Learn R Programming

asremlPlus (version 2.0-9)

asremlPlus-deprecated: Deprecated Functions in Package asremlPlus

Description

These functions have been renamed and deprecated in asremlPlus: addrm.terms.asreml replaced by addrm.terms.asrtests, choose.model.asreml by choose.model.asrtests, recalc.wald.tab.asreml by recalc.wald.tab.asrtests, rmboundary.asreml by rmboundary.asrtests, sig.devn.reparam.asreml by sig.devn.reparam.asrtests, testranfix.asreml by testranfix.asrtests, testrcov.asreml by testrcov.asrtests, testswapran.asreml by testswapran.asrtests, info.crit by info.crit.asreml, reml.lrt by reml.lrt.asreml

Usage

addrm.terms.asreml(...) choose.model.asreml(...) recalc.wald.tab.asreml(...) rmboundary.asreml(...) sig.devn.reparam.asreml(...) testranfix.asreml(...) testrcov.asreml(...) testswapran.asreml(...) info.crit(...) reml.lrt(...)

Arguments

...
absorbs arguments passed from the old functions of the style foo.bar().