An object of S3-class asrtests that contains information derived from the fits of
a mixed model using asreml.
as.asrtests is function that makes an object of this class.
is.list is the membership function for this class; it tests
that an object is of class list.
validAsrtests can be used to test the validity of an
asrtests.object.
A list that contains three components:
asreml.obj: an object of class asreml that contains
the fit of a model;
wald.tab: A data.frame containing a pseudo-anova
table for the fixed terms produced by wald.asreml. It has
rownames that corresond to the fixed terms that were
fitted and four columns. If denominator degrees of freedom were
calculated then the columns are Df, denDF,
F.inc, Pr; otherwise the columns are Df,
Sum of Sq, Wald statistic, and Pr(Chisq).
test.summary: A data.frame with columns term,
DF, denDF, p and action. A row is added to
it for each term
that is dropped, added or tested or a note that several terms have been
added or removed. A row contains the name of the term, the
DF, the p-value and the action taken. Possible codes are:
Dropped, Retained, Swapped, Unswapped,
Significant, Nonsignificant, Absent, Added,
Removed and Boundary. If the changed model did not
converge, Unconverged will be added to the code.
Note that the logical asreml.obj$converge also
reflects whether there is convergence.