Learn R Programming

asremlPlus (version 2.0-2)

info.crit.asreml: Computes AIC and BIC for a model.

Description

Computes Akiake and Bayesian (Schwarz) Information Criteria for a model. The function info.crit is provided for backwards compatibility.

Usage

info.crit.asreml(asreml.obj)

Arguments

asreml.obj
An asreml object resulting from the fitting of a model using REML.

Value

  • A data frame containing the Residual degrees of freedom, AIC, BIC and log of the REML value.

See Also

reml.lrt.asreml

Examples

Run this code
data(Wheat.dat)
   current.asr <- asreml(yield ~ Rep + WithinColPairs + Variety, 
                         random = ~ Row + Column + units,
                         rcov = ~ ar1(Row):ar1(Column), 
                         data=Wheat.dat)
    info.crit.asreml(current.asr)

Run the code above in your browser using DataLab