Usage
newfit.asreml(asreml.obj, fixed., random., sparse., rcov., update = TRUE, keep.order = TRUE, set.terms = NULL, ignore.suffices = TRUE, constraints = "P", initial.values = NA, ...)
Arguments
asreml.obj
a valid asreml object with with
a component named call (from a previous
call to either asreml or update.asreml).
fixed.
a character or formula specifying changes to the fixed
formula. This is a two-sided formula
where "." is substituted for existing components in the
fixed component of asreml.obj$call.
random.
a character or formula specifying changes to the random
formula. This is a one-sided formula
where "." is substituted for existing components in the
random component of asreml.obj$call.
sparse.
a character or formula specifying changes to the sparse
formula. This is a one-sided formula
where "." is substituted for existing components in the
sparse component of asreml.obj$call.
rcov.
a character or formula specifying changes to the error
formula. This is a one-sided formula
where "." is substituted for existing components in the
rcov component of asreml.obj$call.
update
a logical indicated whether to use update.asreml or
asreml to evaluate the modified call.
If TRUE, use update.asreml to evaluate the
modified call. In doing this the arguments
R.param and G.param are set to those in the
asreml.obj so that the values from the previous
model are used as starting values. If FALSE then a
call is made to asreml itself, in which the only
changes from the previous call are those specified in the
arguments to newfit.asreml.
keep.order
a logical value indicating whether the terms should keep
their positions. If FALSE the terms are reordered so
that main effects come first, followed by the interactions,
all second-order, all third-order and so on. Effects of a
given order are kept in the order specified.
set.terms
a character vector specifying the terms that are to have
constraints and/or initial values set prior to fitting.
ignore.suffices
a logical vector specifying whether the suffices of the
asreml-assigned names of the variance terms (i.e. the
information to the right of an "!", other than "R!") is to
be ignored in matching elements of terms.
If TRUE for an element of terms, the suffices
are stripped from the asreml-assigned names.
If FALSE for an element of terms, the element
must exactly match an asreml-assigned name for a
variance term. This vector must be of length one or the
same length as terms. If it is of length one then
the same action is applied to the asreml-assigned
suffices for all the terms in terms.
constraints
a character vector specifying the constraints to be applied
to the terms specified in terms. This vector
must be of length one or the same length as terms.
If it is of length one then the same constraint is
applied to all the terms in terms.
If any of the constraints are equal to NA then they are
left unchanged for those terms.
initial.values
a character vector specifying the initial values for
the terms specified in terms. This vector
must be of length one or the same length as terms.
If it is of length one then the same initial value is
applied to all the terms in terms.
If any of the initial.values are equal to NA then they are
left unchanged for those terms.
...
additional arguments to the call, or arguments with changed
values.