denDF
Specifies the method to use in computing approximate denominator
degrees of freedom when wald.asreml is called. Can be none
to suppress the computations, numeric for numerical methods,
algebraic for algebraic methods or default, the default,
to autommatically choose numeric or algebraic computations depending
on problem size. The denominator degrees of freedom are calculated
according to Kenward and Roger (1997) for fixed terms in the dense
part of the model.
dDF.na
The method to use to obtain substitute denominator degrees of freedom.
when the numeric or algebraic methods produce an NA. If
dDF.na = "none", no subtitute denominator degrees of freedom
are employed; if dDF.na = "residual",
the residual degrees of freedom from asreml.obj$nedf are used;
if dDF.na = "maximum", the maximum of those denDF that are available,
excluding that for the Intercept, is used; if all denDF are NA,
asreml.obj$nedf is used. If dDF.na = "supplied",
a vector of values for the denominator degrees of freedom is to
be supplied in dDF.values. Any other setting is ignored and
a warning message produced. Generally, substituting these degrees of freedom is
anticonservative in that it is likely that the degrees of freedom used will be
too large.
dDF.values
A vector of values to be used when dDF.na = "supplied".
Its values will be used when denDF in a test for a fixed effect
is NA. This vector must be the same length as the number of
fixed terms, including (Intercept) whose value could be NA.