Learn R Programming

asremlPlus (version 2.0-9)

reml.lrt.asreml: Performs REML likelihood ratio test.

Description

Extracts the REML log likelhood and number of variance parameters from two asreml objects. It assumes that the second asreml object is the result of fitting a model that is a reduced version of the model for the first object. In the case where the reduced model is obtained by setting positively-constrained variance parameters in the full model to zero, the positive.zero argument should be set to TRUE so that the p-value is computed using a mixture of chi-square distributions as described in Self and Liang (1987). The function shecks that the models do not differ in either their fixed or sparse models. The function reml.lrt is provided for backwards compatibility.

Usage

reml.lrt.asreml(full.asreml.obj, reduced.asreml.obj, positive.zero=FALSE)

Arguments

full.asreml.obj
asreml object for the full model.
reduced.asreml.obj
asreml object for the reduced model.
positive.zero
Indicates whether the hypothesized values for the varaince components being tested are on the boundary of the parameter space. For example, this is be true for positively-constrained variance components that, under the reduced model, are zero.

Value

freedom and its p-value.

References

Self, S.G., and Liang, K-Y. (1987) Asymptotic Properties of Maximum Likelihood Estimators and Likelihood Ratio Tests Under Nonstandard Conditions. Journal of the American Statistical Association, 82, 605-10.

See Also

info.crit.asreml, testranfix.asrtests