Learn R Programming

asremlPlus (version 2.0-2)

rmboundary.asrtests: Removes any boundary or singular variance components from the fit stored in asreml.obj and records their removal in a data.frame.

Description

Any terms specified in the random model that are estimated on the boundary or are singular and can be removed are removed from the fit stored in an asreml object. Terms that specify multiple parameters in the random model cannot be removed (e.g. terms specified using the at function with more than one level of the factor) and terms in rcov model are not removed. Terms that can be removed are selected for removal in the following order based on whether they involve: (i) a dev function, (ii) only factors, (iii) an spl function, (iv) a pol function and (v) a lin function or a variable that is an integer or a numeric. It should be noted that this order of removal presumes that random deviation terms are specified via the dev function rather than via a random factor. Once the earliest of thes above classes with a boundary term is identified, a term within this class is selected for removal. For all classes, except for factor-only terms, the smallest term with the largest number of variables/factors is removed. Amongst factor-only terms, the smallest term with the smallest number of variables/factors is removed. After each variance component is removed, a row for it is added to the test.summary data.frame and the model refitted. If there are further boundary or singular terms, one is removed using the above strategy. This process continues until there are no further boundary or singular variance components that are removable. Other types of boundary or singular terms, which cannot be removed, are reported in warning messages.

Usage

rmboundary.asrtests(asrtests.obj, trace = FALSE, update = TRUE,
                    set.terms = NULL, ignore.suffices = TRUE, 
                    constraints = "P", initial.values = NA, ...)

Arguments

asrtests.obj
an asrtests object for a fitted model that is a list containing an asreml object, a wald.tab data.frame with 4 columns, and a
trace
if TRUE then partial iteration details are displayed when ASReml-R functions are invoked; if FALSE then no output is displayed.
update
if TRUEthen update.asreml is called to fit the model with any boundary terms removed. In doing this the arguments R.param and G.param are set to those in the asreml<
set.terms
a character vector specifying the terms that are to have constraints and/or initial values set prior to fitting.
ignore.suffices
a logical vector specifying whether the suffices of the asreml-assigned names of the variance terms (i.e. the information to the right of an "!", other than "R!") is to be igno
constraints
a character vector specifying the constraints to be applied to the terms specified in terms. This vector must be of length one or the same length as terms. If it i
initial.values
a character vector specifying the initial values for the terms specified in terms. This vector must be of length one or the same length as terms. If it is of leng
...
further arguments passed to asreml.

Value

  • An asrtests object, which is a list containing:
    1. asreml.obj: anasremlobject containing the fit of the model after all boundary and singular terms have been removed;
    2. wald.tab: a 4-columndata.framecontaining a pseudo-anova table for the fixed terms produced bywald.asreml;
    3. test.summary: adata.framewith columnsterm,DF,denDF,pandaction. A row is added to it for each of the boundary terms removed, the row containing the name of the term, one for the DF, NA for the p-value andBoundaryfor the action.

See Also

asrtests, addrm.terms.asrtests, testranfix.asrtests, testrcov.asrtests, newfit.asreml, sig.devn.reparam.asrtests, choose.model.asrtests

Examples

Run this code
current.asrt <- rmboundary.asrtests(current.asrt)

Run the code above in your browser using DataLab