Arguments
call
an unevaluated call to asreml. One way to create
such a call is to use the call function with
its name argument set to "asreml". Another is to
obtain it from the call component of an asreml
object (e.g. call <- asreml.obj$call).
terms
a character vector specifying the terms
that are to have constraints and/or initial values specified.
ignore.suffices
a logical vector specifying whether the suffices of the
asreml-assigned names of the variance terms (i.e. the
information to the right of an "!", other than "R!") is to be ignored in
matching elements of terms. If TRUE for
an element of terms, the suffices are stripped
from the asreml-assigned names. If FALSE for
an element of terms, the element must exactly match
an asreml-assigned name for a variance term. This vector
must be of length one or the same length as terms.
If it is of length one then the same action is
applied to the asreml-assigned suffices for all the terms
in terms.
constraints
a character vector specifying the constraints to be applied
to the terms specified in terms. This vector
must be of length one or the same length as terms.
If it is of length one then the same constraint is
applied to all the terms in terms.
If any of the constraints are equal to NA then they are
left unchanged for those terms.
initial.values
a character vector specifying the initial values for
the terms specified in terms. This vector
must be of length one or the same length as terms.
If it is of length one then the same initial value is
applied to all the terms in terms.
If any of the initial.values are equal to NA then they are
left unchanged for those terms.
...
additional arguments to be added to the call, or arguments in
the call with changed values.