asreml and tests whether the change
is significant.asreml and tests whether the
change is significant. If simpler = FALSE the model to be fitted
must be more complex than the one whose fit has been stored in
asrtests.obj. That is, the new model must have more parameters.
However, if simpler = TRUE the model to be fitted must be simpler
than the one whose fit has been stored in asrtests.obj in that it
must have fewer parameters. Any boundary terms are removed using
rmboundary.asrtests, which may mean that the models are not
nested. The test is a REML likelihood ratio test that is performed using
reml.lrt.asreml, which is only valid if the models are nested.
It compares the newly fitted model with the fit of the model in
asrtest.obj. A row is added to the test.summary
data.frame using the supplied label.testrcov.asrtests(terms=NULL, asrtests.obj, label = "R model", simpler = FALSE, alpha = 0.05, positive.zero = FALSE, denDF="default", update = TRUE, trace = FALSE, set.terms = NULL, ignore.suffices = TRUE, constraints = "P", initial.values = NA, ...)rcov argument in asreml, stored
as a character.asrtests object for a fitted model that is a list
containing an asreml object, a wald.tab
data.frame with 4 columns, and a data.frame with
5 columns that records any previous changes and tests in the
fitted model.test.summary and
which indicates what is being tested.asrtests.obj.wald.asreml is called. Can be none
to suppress the computations, numeric for numerical methods,
algebraic for algebraic methods or default, the default,
to autommatically choose numeric or algebraic computations depending
on problem size. The denominator degrees of freedom are calculated
according to Kenward and Roger (1997) for fixed terms in the dense
part of the model.TRUE then update.asreml is called to fit the model with
the rcov model supplied in terms. In doing this the arguments
R.param and G.param are set to those in the asreml
object stored in asrtests.obj so that the values from the previous
model are used as starting values. If FALSE then a call is made to
asreml in which the only changes from the previous call are that
(i) rcov model is that specified in terms and
(ii) modifications specified via ... are made.asreml-assigned names of the variance terms (i.e. the
information to the right of an "!", other than "R!") is to
be ignored in matching elements of terms.
If TRUE for an element of terms, the suffices
are stripped from the asreml-assigned names.
If FALSE for an element of terms, the element
must exactly match an asreml-assigned name for a
variance term. This vector must be of length one or the
same length as terms. If it is of length one then
the same action is applied to the asreml-assigned
suffices for all the terms in terms.terms. This vector
must be of length one or the same length as terms.
If it is of length one then the same constraint is
applied to all the terms in terms.
If any of the constraints are equal to NA then they are
left unchanged for those terms.terms. This vector
must be of length one or the same length as terms.
If it is of length one then the same initial value is
applied to all the terms in terms.
If any of the initial.values are equal to NA then they are
left unchanged for those terms.asreml and to wald.asreml.asrtests object, which is a list containing:
asreml.obj: an asreml object containing the fit
after the term has been omitted from the model;
wald.tab: a 4-column data.frame containing a
pseudo-anova table for the fixed terms produced by wald.asreml;
test.summary: a data.frame with columns term,
DF, denDF, p and action. A row is added to
it for each term
that is dropped, added or tested or a note that several terms have been
added or removed. A row contains the name of the term, the
DF, the p-value and the action taken. Possible codes are:
Dropped, Retained, Swapped, Unswapped,
Significant, Nonsignificant, Absent, Added,
Removed and Boundary. If the changed model did not
converge, Unconverged will be added to the code.
Note that the logical asreml.obj$converge also
reflects whether there is convergence.term is not in the model, then the supplied asreml
object will be returned. Also, reml.test will have the likelihood
ratio and the p-value set to NA and the degrees of freedom to zero.
Similarly, the row of test.summary for the term will have
its name, a p-value set to NA, and action set to Absent.
asremlPlus-package, asrtests, newrcov.asrtests, choose.model.asrtests,
reml.lrt.asreml, rmboundary.asrtests,
newfit.asreml, testswapran.asrtests,
addrm.terms.asrtests,
sig.devn.reparam.asrtests