update.asreml or a direct call to asreml.asreml.obj and
evaluates that call, replacing any arguments with changed values.
If update is TRUE and set.terms is not set,
the call is evaluated using update.asreml; otherwise,
it is evaluated using a direct call to asreml.
The principal difference is that the latter does not enforce the
use of previous values of the variance parameters as initial
values; it sets G.param and R.param to NULL
or to values as specified for set.terms.
The ... argument can be used to pass G.param
and/or R.param, provided update is FALSE
and set.terms is not set.newfit.asreml(asreml.obj, fixed., random., sparse., rcov.,
update = TRUE, keep.order = TRUE, set.terms = NULL,
ignore.suffices = TRUE, constraints = "P", initial.values = NA, ...)asreml object with with
a component named call (from a previous
call to either asreml or update.asreml).asreml.obj$call.asreml.obj$call.asreml.obj$call.asreml.obj$call.update.asreml or
asreml to evaluate the modified call.
If TRUE, use update.asreml to evaluate the
modified calFALSE the terms are reordered so
that main effects come first, followed by the interactions,
all second-order, allasreml-assigned names of the variance terms (i.e. the
information to the right of an "!", other than "R!") is to
be ignoterms. This vector
must be of length one or the same length as terms.
If it iterms. This vector
must be of length one or the same length as terms.
If it is of lengasreml object.update.asreml, setvarianceterms.asremlm2.asreml <- newfit.asreml(m1.asreml, random. = "~ . - Blocks:Plots", maxiter=75)Run the code above in your browser using DataLab