Usage
newrcov.asrtests(terms=NULL, asrtests.obj, label = "R model",
update = TRUE, trace = FALSE, denDF="default",
set.terms = NULL, ignore.suffices = TRUE,
constraints = "P", initial.values = NA, ...)Arguments
terms
a model for the rcov argument in asreml, stored
as a character.
asrtests.obj
an asrtests object for a fitted model that is a list
containing an asreml object, a wald.tab
data.frame with 4 columns, and a label
a character string to use as the label in test.summary and
which indicates what is being tested.
update
if TRUEthen update.asreml is called to fit the model with
the rcov model supplied in terms. In doing this the arguments
R.param and G.param are s
trace
if TRUE then partial iteration details are displayed when ASReml-R
functions are invoked; if FALSE then no output is displayed.
denDF
Specifies the method to use in computing approximate denominator
degrees of freedom when wald.asreml is called. Can be none
to suppress the computations, numeric for numerical methods,
set.terms
a character vector specifying the terms that are to have
constraints and/or initial values set prior to fitting.
ignore.suffices
a logical vector specifying whether the suffices of the
asreml-assigned names of the variance terms (i.e. the
information to the right of an "!", other than "R!") is to
be igno
constraints
a character vector specifying the constraints to be applied
to the terms specified in terms. This vector
must be of length one or the same length as terms.
If it i
initial.values
a character vector specifying the initial values for
the terms specified in terms. This vector
must be of length one or the same length as terms.
If it is of leng
...
further arguments passed to asreml and to wald.asreml.