alldiffs object to form, for those components not already present,
(i) a table of all pairwise differences of the predictions in an alldiffs
object, (ii) the p-values of each pairwise difference, and (iii) the minimum, mean and
maximum LSD values. Predictions that are aliased (or nonestimable) are removed
from the predictions component of the alldiffs object and
standarard errors of differences involving them are removed from the sed component.
Each p-value is computed as the probability of a t-statistic as large as or larger than
the absolute value of the observed difference divided by its standard error. The
p-values are stored in the p.differences component. The degrees of freedom of
the t-distribution is the degrees of freedom stored in the tdf attribute of the
alldiffs object. This t-distibrution is also used in calculating the
LSD statistics stored in the alldiffs object.predictiondiffs.asreml(classify, alldiffs.obj,
x.num = NULL, x.fac = NULL,
levels.length = NA,
pairwise = TRUE, alpha = 0.05,
inestimable.rm = TRUE)alldiffs object for a fitted model. Note that the
attribute tdf, being the degrees of freedom for the critical
t-value to be used incomputing p-values, shox.fac, is potentially included in terms in the
fitted model and which corresponds to the x-axis variable. It should
x.num, is potentially included in terms in the fitted model and
which corresponds to the x-axis variable. It should have the same
predictions and their standard errors and p-values are to be
computed and stored. If FALSE, the components differences
logical indicating whether rows for predictions that
are not estimable are to be removed from the components of the
alldiffs object.alldiffs object that is a list with components
predictions containing the predictions and
their standard errors, differences containing all pairwise
differences between the predictions, p.differences containing
p-values for all pairwise differences between the predictions,
sed containing the standard errors of all pairwise differences
between the predictions, and,an LSD containing the mean, minimum
and maximum LSDs.asremlPlus-package, alldiffs,
print.alldiffs, predictionplot.asreml,
predictparallel.asreml, pred.present.asremlVar.pred <- predict(current.asr, classify="Variety", sed=TRUE)$predictions
wald.tab <- current.asrt$wald.tab
den.df <- wald.tab[match("Variety", rownames(wald.tab)), "denDF"]
Var.diffs <- alldiffs(predictions = Var.pred$pvals,
sed = Var.pred$sed,
tdf = den.df)
Var.diffs <- predictiondiffs.asreml(classify = "Variety",
alldiffs.obj=Var.diffs)
print.alldiffs(Var.diffs, which="differences")Run the code above in your browser using DataLab