Learn R Programming

asremlPlus (version 2.0-2)

recalc.wald.tab.asrtests: Recalculates the denDF, F.inc and P values for a table of Wald test statistics obtained using wald.asreml

Description

If some or all denDF are not available, either because they are NA or because F.inc values were not calculated, this function allows the user to specify how a approximate denDF values are to be obtained. This is done through the dDF.na and dDF.values arguments. Note that if denDF values are available in the Wald table then only those that are NA will be replaced.

Usage

recalc.wald.tab.asrtests(asrtests.obj, recalc.wald = FALSE,
                         denDF="default", dDF.na = "none", 
                         dDF.values = NULL, trace = FALSE, ...)

Arguments

asrtests.obj
an asrtests object for a fitted model that is a list containing an asreml object, a wald.tab data.frame with 4 columns, and a
recalc.wald
a logical indicating whether to call wald.asreml to recalculate the pseudoanova table for the model fit stored in the asreml object contained in
denDF
Specifies the enthod to use in computing approximate denominator degrees of freedom when wald.asreml is called. Can be none to suppress the computations, numeric for numerical methods,
dDF.na
the method to use to obtain substitute denominator degrees of freedom. when the numeric or algebraic methods produce an NA. If dDF.na = "none", no subtitute denominator degrees of freedom
dDF.values
A vector of values to be used when dDF.na = "supplied". Its values will be used when denDF in a test for a fixed effect is NA. This vector must be the same length as the nu
trace
if TRUE then partial iteration details are displayed when ASReml-R functions are invoked; if FALSE then no output is displayed.
...
further arguments passed to asreml and to wald.asreml.

Value

  • A wald.tab: a 4-column data.frame containing a pseudo-anova table for the fixed terms produced by wald.asreml.

See Also

asrtests, testranfix.asrtests

Examples

Run this code
wald.tab <- recalc.wald.tab.asrtests(current.asrt, 
                                       dDF.na = "supplied", 
                                       dDF.values = c(NA,rep(c(330,346), c(4,3))))

Run the code above in your browser using DataLab