wald.asremldDF.na and
dDF.values arguments. Note that if denDF values are available in the Wald table then
only those that are NA will be replaced.recalc.wald.tab.asrtests(asrtests.obj, recalc.wald = FALSE,
denDF="default", dDF.na = "none",
dDF.values = NULL, trace = FALSE, ...)asrtests object for a fitted model that is a list
containing an asreml object, a wald.tab
data.frame with 4 columns, and a logical indicating whether to call wald.asreml to recalculate
the pseudoanova table for the model fit stored in the asreml object
contained in wald.asreml is called. Can be none
to suppress the computations, numeric for numerical methods,NA. If
dDF.na = "none", no subtitute denominator degrees of freedom
vector of values to be used when dDF.na = "supplied".
Its values will be used when denDF in a test for a fixed effect
is NA. This vector must be the same length as the nuasreml and to wald.asreml.wald.tab: a 4-column data.frame containing a
pseudo-anova table for the fixed terms produced by wald.asreml.asrtests, testranfix.asrtestswald.tab <- recalc.wald.tab.asrtests(current.asrt,
dDF.na = "supplied",
dDF.values = c(NA,rep(c(330,346), c(4,3))))Run the code above in your browser using DataLab