asreml objects. It assumes that the second
asreml object is the result of fitting a model that is a
reduced version of the model for the first object. In the case
where the reduced model is obtained by setting positively-constrained
variance parameters in the full model to zero, the positive.zero
argument should be set to TRUE so that
the p-value is computed using a mixture of chi-square distributions as
described in Self and Liang (1987).
The function shecks that the models do not differ in either their fixed
or sparse models.
The function reml.lrt is provided for backwards compatibility.reml.lrt.asreml(full.asreml.obj, reduced.asreml.obj, positive.zero=FALSE)asreml object for the full model.asreml object for the reduced model.info.crit.asreml, testranfix.asrtestsreml.lrt.asreml(ICV.max, ICV.red, positive.zero=TRUE)Run the code above in your browser using DataLab