Usage
rmboundary.asrtests(asrtests.obj, trace = FALSE, update = TRUE, set.terms = NULL, ignore.suffices = TRUE, constraints = "P", initial.values = NA, ...)
Arguments
asrtests.obj
an asrtests object for a fitted model that is a list
containing an asreml object, a wald.tab
data.frame with 4 columns, and a data.frame with
5 columns that records any previous changes and tests in the
fitted model. trace
if TRUE then partial iteration details are displayed when ASReml-R
functions are invoked; if FALSE then no output is displayed.
update
if TRUE then update.asreml is called to fit the model with
any boundary terms removed. In doing this the arguments
R.param and G.param are set to those in the asreml
object stored in asrtests.obj so that the values from the previous
model are used as starting values. If FALSE then a call is made to
asreml in which the only changes from the previous call are that
(i) the terms for boundary variance components are removed
from the models and (ii) modifications specified via ... are made.
set.terms
a character vector specifying the terms that are to have
constraints and/or initial values set prior to fitting.
ignore.suffices
a logical vector specifying whether the suffices of the
asreml-assigned names of the variance terms (i.e. the
information to the right of an "!", other than "R!") is to
be ignored in matching elements of terms.
If TRUE for an element of terms, the suffices
are stripped from the asreml-assigned names.
If FALSE for an element of terms, the element
must exactly match an asreml-assigned name for a
variance term. This vector must be of length one or the
same length as terms. If it is of length one then
the same action is applied to the asreml-assigned
suffices for all the terms in terms.
constraints
a character vector specifying the constraints to be applied
to the terms specified in terms. This vector
must be of length one or the same length as terms.
If it is of length one then the same constraint is
applied to all the terms in terms.
If any of the constraints are equal to NA then they are
left unchanged for those terms.
initial.values
a character vector specifying the initial values for
the terms specified in terms. This vector
must be of length one or the same length as terms.
If it is of length one then the same initial value is
applied to all the terms in terms.
If any of the initial.values are equal to NA then they are
left unchanged for those terms.
...
further arguments passed to asreml.