variogram based on residuals produced after the fitting of a model
using the function asreml.
It also adds envelopes to the plot by simulating data sets from a
multivariate normal distribution with expectation equal to the
fitted values obtained from the fixed and spline terms and variance
matrix equal to the fitted variance matrix
(Stefanova, Smith & Cullis, 2009). The plot is constrolled by the
rcov model, which must consist of two factors corresponding to
the two physical dimensions underlying the data. It can also have a third
term involving the at function that defines sections of the data,
such as experiments in different environments. In this case, the two
variogram faces are produced for each section.variofaces.asreml(object, means=NULL, V, nsim=100, seed = NULL, tolerance=1E-10, units = "ignore", update = TRUE, trace = FALSE, graphics.device=NULL, ...)asreml object from a call to asreml in which the
data argument has been set.vector of means to be used in generating simulated data sets. If
it is NULL, the fitted values based on object are used.
It must be the same length as the response variable for object.matrix, i.e. having the appropriate pattern and values
given the model fitted to the observed data and the estimates of the
parameters obtained.character indicating whether the BLUPs for units are
added to the residuals when this reserved factor is included in the
random model. Possible values are addtoresiduals and
ignore. If standardized conditional residuals are plotted and
the BLUPs for units are to be added then it is the standardized
BLUPs that are added.TRUE then the arguments R.param
and G.param are set to those in the asreml object
supplied in object so that the values from the original
model are used as starting values. If FALSE then calls are made to
asreml in which the only changes from the previous call are
(i) the model is fitted to simulated data and (ii) modifications
specified via ... are made, except that changes cannot be made to
any of the models.character specifying a graphics device for plotting.
The default is graphics.device = NULL, which will result
in plots being produced on the current graphics device. Setting it to
"windows", for example, will result in a windows graphics
device being opened.asreml. Changes
to the models are not allowed. Other changes are dangerous and generally
should be avoided.list with the following components:
data.frame containing the variogram values on
which the plot for the first dimension is based.
data.frame containing the variogram values on
which the plot for the second dimension is based.rcov model is scanned to ensure that it involves only two factors
not included in the at function, and to see if it has a third factor in
an at function. If so, the faces of the 2D variogram, each based on one
of the two non-at factors, are derived from the residuals in the
supplied asreml object using asreml.variogram, this yielding the observed
variogram faces. If aom was set to TRUE for the asreml
object, the standardized consitional residuals are used.
Then nsim data sets are generated by
adding the fitted.values, extracted from the asreml object,
to a vector of values randomly generated from a normal distribution with
expectation zero and variance matrix V. Each data set is analyzed
using the model in object and the variogram values for the faces are
obtained using asreml.variogram stored. Note, if the analysis for a
data set does not converge in maxiter iterations, it is discarded and
a replacement data set generated. The value of maxiter can be specified
in the call to variofaces.asreml. Plots are produced for each face and
include the observed values and the 2.5%, 50% & 97.5% quantiles.asremlPlus-package, asreml,
plotvariofaces.asreml, simulate.asreml.